summaryrefslogtreecommitdiff
path: root/src/nautilus-file.c
diff options
context:
space:
mode:
authorAntónio Fernandes <antoniof@gnome.org>2022-08-04 22:59:11 +0100
committerAntónio Fernandes <antoniof@gnome.org>2022-08-05 20:14:07 +0000
commit5ceca92beac1bee76f80338d1ca0580a710948c7 (patch)
treeb895dd83da5c213bf83d51297e1f306121f7a714 /src/nautilus-file.c
parent814a5112f1bc4ebcf44321974289b0e4ebef7ef5 (diff)
downloadnautilus-5ceca92beac1bee76f80338d1ca0580a710948c7.tar.gz
file: Follow HIG in own username
"You" is preferrable to "Me" https://developer.gnome.org/hig/guidelines/writing-style.html#guidelines
Diffstat (limited to 'src/nautilus-file.c')
-rw-r--r--src/nautilus-file.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/nautilus-file.c b/src/nautilus-file.c
index 3ad25dc99..ce00418ce 100644
--- a/src/nautilus-file.c
+++ b/src/nautilus-file.c
@@ -6829,8 +6829,8 @@ nautilus_file_get_owner_as_string (NautilusFile *file,
if (include_real_name &&
file->details->uid == getuid ())
{
- /* Translators: "Me" is used to indicate the file is owned by me (the current user) */
- user_name = g_strdup (_("Me"));
+ /* Translators: This is a username followed by "(You)" to indicate the file is owned by the current user */
+ user_name = g_strdup_printf (_("%s (You)"), file->details->owner);
}
else if (file->details->owner_real == NULL)
{